/*
 * Filesystem opening functions.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include "fs.h"



/* Block server access configuration. */

extern io_manager blockserver_io_manager;
extern const char *blockserver_default_cap;



/* Set the capability name used to access the underlying block server. */

void e2access_init(const char *cap)
{ 
  blockserver_default_cap = cap;
}

/* Open a filesystem provided by the indicated filename, using the given flags
   and updating the filesystem reference. Any error is returned. */

errcode_t e2access_open(const char *filename, int flags, ext2_filsys *fs)
{ 
  errcode_t retval = ext2fs_open(filename, flags, 0, 0, blockserver_io_manager, fs);
  
  if (retval)
    return retval;
  
  return ext2fs_read_bitmaps(*fs);
}   

// vim: tabstop=2 expandtab shiftwidth=2
