/*
 * Show concatenated filesystem object contents.
 *
 * Copyright (C) 2024 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <stdio.h>



/* Transfer size for communication. */

static const offset_t TO_TRANSFER = 1024;



/* Show an object from the filesystem. */

static int show_object(const char *path)
{
    char *buffer[TO_TRANSFER];
    FILE *file = fopen(path, "r");
    size_t nread;

    if (file == NULL)
        return 1;

    while ((nread = fread(buffer, sizeof(char), TO_TRANSFER, file)))
    {
        if (!fwrite(buffer, sizeof(char), nread, stdout))
            break;
    }

    fclose(file);

    return 0;
}

/* List objects in the filesystem image. */

int main(int argc, char *argv[])
{
    int i;

    /* Show all specified objects. */

    for (i = 1; i < argc; i++)
    {
        if (show_object(argv[i]))
            return 1;
    }

    return 0;
}

/* vim: tabstop=4 expandtab shiftwidth=4
*/
